searchData={"items":[{"type":"module","title":"Doumi.Test","doc":"","ref":"Doumi.Test.html"},{"type":"module","title":"Doumi.Test.Assertions","doc":"","ref":"Doumi.Test.Assertions.html"},{"type":"macro","title":"Doumi.Test.Assertions.assert_same_fields/3","doc":"Assert that two maps have the same value for a given fields.\nThe two maps must always contain the given field.","ref":"Doumi.Test.Assertions.html#assert_same_fields/3"},{"type":"macro","title":"Examples - Doumi.Test.Assertions.assert_same_fields/3","doc":"iex> assert_same_fields %{a: 1, b: 2}, %{a: 1, b: 2}, [:a, :b]\n    true\n\n    iex> assert_same_fields %{a: 1, b: 2}, %{a: 1, b: 3}, [:a, :b]\n    ** (ExUnit.AssertionError)\n\n    The two maps have different values for the given fields","ref":"Doumi.Test.Assertions.html#assert_same_fields/3-examples"},{"type":"macro","title":"Doumi.Test.Assertions.assert_same_records/2","doc":"Assert that two records have the same primary keys.","ref":"Doumi.Test.Assertions.html#assert_same_records/2"},{"type":"macro","title":"Examples - Doumi.Test.Assertions.assert_same_records/2","doc":"iex> assert_same_records %TestModule1{id: 1}, %TestModule1{id: 1}\n    true\n\n    iex> assert_same_records %TestModule1{id: 1}, %TestModule1{id: 2}\n    ** (ExUnit.AssertionError)\n\n    The two records have different primary keys","ref":"Doumi.Test.Assertions.html#assert_same_records/2-examples"},{"type":"macro","title":"Doumi.Test.Assertions.assert_same_values/2","doc":"Assert that two values are the same.","ref":"Doumi.Test.Assertions.html#assert_same_values/2"},{"type":"macro","title":"Examples - Doumi.Test.Assertions.assert_same_values/2","doc":"iex> assert_same_values 1, 1\n    true\n\n    iex> assert_same_values 1, 2\n    ** (ExUnit.AssertionError)\n\n    `1` and `2` are not the same values","ref":"Doumi.Test.Assertions.html#assert_same_values/2-examples"},{"type":"module","title":"Doumi.Test.Comparison","doc":"","ref":"Doumi.Test.Comparison.html"},{"type":"function","title":"Doumi.Test.Comparison.same_fields?/3","doc":"Compare two maps have the same value for a given fields.\nThe two maps must always contain the given field.","ref":"Doumi.Test.Comparison.html#same_fields?/3"},{"type":"function","title":"Examples - Doumi.Test.Comparison.same_fields?/3","doc":"iex> Doumi.Test.Comparison.same_fields?(%{a: 1, b: 2}, %{a: 1, b: 2}, [:a, :b])\n    true\n\n    iex> Doumi.Test.Comparison.same_fields?(%{a: 1, b: 2}, %{a: 1, b: 3}, [:a, :b])\n    false\n\n    iex> Doumi.Test.Comparison.same_fields?(%{a: 1}, %{a: 1, b: 2}, [:a, :b])\n    ** (KeyError) key :b not found in: %{a: 1}","ref":"Doumi.Test.Comparison.html#same_fields?/3-examples"},{"type":"function","title":"Doumi.Test.Comparison.same_records?/2","doc":"Compare two records have the same primary keys.","ref":"Doumi.Test.Comparison.html#same_records?/2"},{"type":"function","title":"Doumi.Test.Comparison.same_values?/2","doc":"Compare two values for equality.","ref":"Doumi.Test.Comparison.html#same_values?/2"},{"type":"function","title":"Examples - Doumi.Test.Comparison.same_values?/2","doc":"iex> Doumi.Test.Comparison.same_values?(1, 1)\n    true\n\n    iex> Doumi.Test.Comparison.same_values?(\"foo\", \"bar\")\n    false\n\n    iex> Doumi.Test.Comparison.same_values?(~U[2023-01-01 00:00:00Z], ~U[2023-01-01 00:00:00.000Z])\n    true\n\n    iex> Doumi.Test.Comparison.same_values?(Decimal.new(\"1.1\"), 1.1)\n    true","ref":"Doumi.Test.Comparison.html#same_values?/2-examples"},{"type":"module","title":"Doumi.Test.Ecto","doc":"","ref":"Doumi.Test.Ecto.html"},{"type":"function","title":"Doumi.Test.Ecto.reload/2","doc":"","ref":"Doumi.Test.Ecto.html#reload/2"},{"type":"function","title":"Doumi.Test.Ecto.reload!/2","doc":"","ref":"Doumi.Test.Ecto.html#reload!/2"},{"type":"extras","title":"Overview","doc":"# Doumi.Test\n\n[![Hex Version](https://img.shields.io/hexpm/v/doumi_test.svg)](https://hex.pm/packages/doumi_test)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/doumi_test/)\n[![License](https://img.shields.io/hexpm/l/doumi_test.svg)](https://github.com/nallwhy/doumi_test/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/nallwhy/doumi_test.svg)](https://github.com/nallwhy/doumi_test/commits/main)\n\n \n\n`Doumi.Test` is a helper library that make it easier to test your Elixir codes.\n\n**도우미(Doumi)** means \"helper\" in Korean.","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"### `assert_same_values/2`\n\n```elixir\ndefmodule MyApp.Test do\n  use ExUnit.Case\n  use Doumi.Test\n\n  test \"returns true with the same values\" do\n    number1 = 1\n    number2 = 1.0\n\n    datetime1 = ~U[2023-11-11 00:00:00Z]\n    datetime2 = ~U[2023-11-11 00:00:00.000Z]\n\n    decimal1 = Decimal.new(\"1.1\")\n    decimal2 = 1.1\n\n    # instead of\n    assert number1 == number2\n    assert DateTime.compare(datetime1, datetime2) == :eq\n    assert Decimal.equal?(decimal1, decimal2)\n\n    # do\n    assert_same_values number1, number2\n    assert_same_values datetime1, datetime2\n    assert_same_values decimal1, decimal2\n  end\nend\n```\n\n### `assert_same_fields/3`\n\n```elixir\ndefmodule MyApp.Test do\n  use ExUnit.Case\n  use Doumi.Test\n\n  test \"returns true with the same fields\" do\n    attrs = %{\n      name: \"name\",\n      age: 30,\n      married: false\n    }\n\n    assert {:ok, something} = create_something(attrs)\n\n    # instead of\n    assert something.name == attrs.name\n    assert something.age == attrs.age\n    assert something.married == attrs.married\n\n    # do\n    assert_same_fields something, attrs, [:name, :age, :married]\n  end\nend\n```\n\n### `assert_same_records/2`\n\n```elixir\ndefmodule MyApp.Test do\n  use MyApp.DataCase\n  use Doumi.Test\n\n  test \"returns true with the same records\" do\n    something = insert(:something)\n\n    assert {:ok, fetched_something} = fetch_something(something.primary_key0, something.primary_key1)\n\n    # instead of\n    assert fetched_something.primary_key0 == something.primary_key0\n    assert fetched_something.primary_key1 == something.primary_key1\n\n    # do\n    assert_same_records fetched_something, something\n  end\nend\n```\n\n### `reload/2`, `reload!/2`\n\n```elixir\ndefmodule MyApp.Test do\n  use MyApp.DataCase\n  use Doumi.Test\n\n  test \"reload record\" do\n    counter = insert(:counter)\n\n    assert :ok = increase_counter_and_no_return(counter)\n\n    updated_counter = reload!(counter)\n\n    assert updated_counter.count == counter.count + 1\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `doumi_test` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:doumi_test, \"~> 0.2.0\"}\n  ]\nend\n```\n\nTo configure formatter, add `:doumi_test` to `import_deps` of `.formatter.exs`:\n\n```elixir\n[\n  ...\n  import_deps: [..., :doumi_test]\n]\n```","ref":"readme.html#installation"},{"type":"extras","title":"Doumi\\* - Overview","doc":"All **Doumi** libraries:\n\n- [Doumi.Port](https://github.com/nallwhy/doumi_port): A helper library that makes it easier to use Python, Ruby in Elixir\n- [Doumi.Phoenix.SVG](https://github.com/nallwhy/doumi_phoenix_svg): A helper library that generates Phoenix function components from SVG files.\n- [Doumi.Phoenix.Params](https://github.com/nallwhy/doumi_phoenix_params): A helper library that supports converting form to params and params to form\n- [Doumi.URI.Query](https://github.com/nallwhy/doumi_uri_query): A helper library that encode complicated query of URI.","ref":"readme.html#doumi"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2023 Jinkyou Son (Json)\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"License","doc":"# The MIT License\n\nCopyright (c) 2023 Jinkyou Son (Json)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}